try (fileIn "RW_Material.ms") catch ()
try (fileIn "GTA_Material.ms") catch ()

fn RwToKam m = (
	if (classof m) == Multimaterial do (
		for i = 1 to m.materialList.count do
			m.materialList[i] = RwToKam m.materialList[i]
		return m
	)
	if (classof m) != RW_Mtl do
		return m
	kam = GTA_Mtl()
	kam.amb = m.sp_ambient
	kam.spc = m.sp_specular
	kam.dif = m.sp_diffuse
	kam.color = m.color
	kam.colormap = m.texmap_texture
	kam.use_colormap = kam.colormap != undefined
	kam.alpha = m.coloralpha*255

	kam.use_RF = m.matfxeffect == 3
	kam.Reflection = m.envmap_amount*100
	kam.reflectionmap = m.texmap_envmap
	kam.use_reflectionmap = kam.reflectionmap != undefined

	if m.enSpec do (
		kam.use_SI = true
		kam.spec_power = m.specularity*100
		kam.specularmap = m.specMap
		kam.use_specularmap = kam.specularmap != undefined
	)

	if m.enEnv do (
		kam.use_SAS = true
		kam.blend = m.shininess
	)

	kam
)

fn KamToRw m = (
	if (classof m) == Multimaterial do (
		for i = 1 to m.materialList.count do
			m.materialList[i] = KamToRw m.materialList[i]
		return m
	)
	if (classof m) != GTA_Mtl do
		return m
	rw = RW_Mtl()
	rw.sp_ambient  = m.amb
	rw.sp_specular = m.spc
	rw.sp_diffuse  = m.dif
	rw.color = m.color
	if m.use_colormap do 
		rw.texmap_texture = m.colormap
	rw.coloralpha = m.alpha/255

	-- matfx env map
	if m.use_RF do (
		rw.matfxeffect = 3
		rw.envmap_amount = m.Reflection/100
		if m.use_reflectionmap do
			rw.texmap_envmap = m.reflectionmap
	)

	-- R* reflection
	if m.use_SAS do (
		rw.enEnv = true
		rw.shininess = m.blend
	)

	-- R* specular
	if m.use_SI do (
		rw.enSpec = true
		rw.specularity = m.spec_power/100
		if m.use_specularmap do
			rw.specMap = m.specularmap
	)

	rw
)

utility GtaHelper "GTA helper" (
	button convMatRW "RW to KAM materials" width:140 align:#center
	button convMatKAM "KAM to RW materials" width:140 align:#center
	on convMatRW pressed do ( 
		for o in objects do (
			o.material = RwToKam o.material
		)
	)
	on convMatKAM pressed do ( 
		for o in objects do (
			o.material = KamToRw o.material
		)
	)
)